/**
 * @file
 *
 * Drupal behavior for the edit_ui regions.
 */

(function (Drupal, $) {
  "use strict";

  /**
   * Initialize region views when region is added to collection.
   *
   * @param Drupal.editUi.region.RegionModel model
   *   Region model instance.
   *
   * @listens event:add
   */
  Drupal.editUi.region.collections.regionCollection.on('add', function (model) {
    var view;
    var region = model.get('region');
    var $el = $('[data-edit-ui-region=' + region + ']');

    // Init region view.
    if ($el.length > 0) {
      view = new Drupal.editUi.region.RegionVisualView({
        model: model,
        el: $el
      });
      Drupal.editUi.region.views.regionVisualView.push(view);
    }
  });

  /**
   * edit_ui region Backbone objects.
   */
  Drupal.editUi.region.views = {
    regionVisualView: []
  };

})(Drupal, jQuery);
